# Changelog

All changes between versions will be kept track of in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

Although there have been previous versions of this software, I do not think there have been previous users so this will be the first version that is kept track of.

## 0.1.5 - 2018-05-24
### Added
- Convert from betacode to unicode and back.
    - Case insensitive
    - Diacritic order insensitive
    - Use oxeîa rather than tónos
- This changelog
